@@ -19,7 +19,7 @@ use Try::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
@@ -534,7 +534,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
@@ -725,7 +725,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andy Jack George Hartzell Gregory Oschwald Joe Crotty Mark Fowler Olaf Alders Pedro Melo timgimyee
+=for stopwords Andy Jack George Hartzell Gregory Oschwald Joe Crotty Mark Fowler Grimes Olaf Alders Pedro Melo timgimyee
 
 =over 4
 
@@ -735,10 +735,6 @@ Andy Jack <andyjack@cpan.org>
 
 =item *
 
-Andy Jack <github@veracity.ca>
-
-=item *
-
 George Hartzell <georgewh@gene.com>
 
 =item *
@@ -755,6 +751,10 @@ Mark Fowler <mark@twoshortplanks.com>
 
 =item *
 
+Mark Grimes <mgrimes@cpan.org>
+
+=item *
+
 Olaf Alders <olaf@wundersolutions.com>
 
 =item *
