@@ -8,7 +8,7 @@ use strict;
 use warnings;
 use base qw(Exporter);
 
-our $VERSION = '0.27';
+our $VERSION = '0.28';
 
 my $test = Test::Builder->new;
 
@@ -23,6 +23,8 @@ sub tidyall_ok {
         $conf_file = Code::TidyAll->find_conf_file( \@conf_names, "." );
     }
     $options{quiet} = 1 unless $options{verbose};
+    $test->diag("Using $conf_file for config")
+        if $options{verbose};
     my $ct = Code::TidyAll->new_from_conf_file(
         $conf_file,
         check_only    => 1,
@@ -73,7 +75,7 @@ tidyall
 
 =head1 VERSION
 
-version 0.27
+version 0.28
 
 =head1 SYNOPSIS
 
