@@ -1,6 +1,6 @@
 package Code::TidyAll::Test::Plugin::ReverseFoo;
 
-use Code::TidyAll::Util qw(read_file write_file);
+use File::Slurp::Tiny qw(read_file write_file);
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
